% Post processing for viewing ADC simulation results
addpath('C:/Cppsim/CppSimShared/HspiceToolbox/');

% Clear data and figures
clear all;
figure(1);
clf;

% Set input parameters
Fs=950e6;
BW_analog = 10e6;
lp_i = 3;
colors = ['bgr'];

%% Load new data
x = loadsig('test.tr0');

for i = 1:3,
    if i < length(x),
        order = (i-1)*2;
        out = evalsig(x,['out_sd',num2str(order)]);
        N = 2^floor(log2(length(out)));
        fB = ceil(N*BW_analog/Fs);

        %% Evaluate second order ADC
        spec=fft(out(1:N).*hann(N)')/N;
        semilogx(Fs/N*(0:1:(N/2-1)),20*log10(abs(spec(1:N/2)))-20*log10(31/8),colors(i),'Linewidth',1.5);
        axis([1e5 Fs/2 -160 0]);
        hold on;
        grid on;

        % Calculate SNR and SNDR
        [a,f] = max(spec(lp_i:fB));
        f = f+lp_i-1;
        snr = calculateSNR(spec(1:fB),f-1,1,3);
        sndr = calculateSNDR(spec(3:fB),f-3);
        s(i,:) = sprintf('Loop order = %d, SNR = %4.1fdB, SNDR = %4.1fdB\n',order,snr,sndr);
    end
end

% Insert legend and labels
legend(s,4);
xlabel('Frequency (Hz)');
ylabel('Amplitude (dB)');

%% Clear data
clear x;

